# -*- coding: utf-8 -*-
from setuphelpers import *

appli_list = ['vim', 'locate', 'ssh', 'rsync', 'arping', 'traceroute', 'nmap', 'telnet', 'iftop',
'dnsutils', 'ethtool', 'iotop', 'screen', 'less', 'psmisc', 'ntpdate', 'tcpdump', 'tree',
'pciutils', 'usbutils', 'lsof', 'mtr-tiny', 'tmux', 'strace', 'htop', 'netcat-openbsd',
'sudo', 'apt-transport-https', 'net-tools', 'gnupg2','ntp','lsb-release','dos2unix','curl']

use_apt_packages = False
use_swapfile = False
use_vim = False
use_old_naming = False
use_bashrc = False
pdiff = False

def install():
    print('Installing %s' % control.asrequirement())

    if 'tisadmin' in run('users'):
        print('Please disconnect tisadmin user before install this package')
        return "ERROR"

    if use_apt_packages:
        for appli in appli_list:
            print(f'Install {appli}')
            install_apt(appli)

    if use_swapfile:
        print('Create swapfile')
        swapfile = makepath('/var','swapfile')
        if not isfile(swapfile):
            run(f'dd if=/dev/zero of={swapfile} bs=1M count=1024')
            run(f'chmod 0600 {swapfile}')
            run(f'mkswap -c {swapfile}')
            run(f'swapon {swapfile}')
            run(f'echo "{swapfile}   none    swap    sw      0 0" >> /etc/fstab')
            run('mount -a')

    if use_vim:
        print('Configure vim')
        vim_version = installed_softwares('vim')[0]['version'].split(':')[1].split('-')[0]
        vim_version = vim_version.split('.')[0] + vim_version.split('.')[1]
        vim_path = f'/usr/share/vim/vim{vim_version}/defaults.vim'
        vim_path_dir = f'/usr/share/vim/vim{vim_version}'

        if not isdir(vim_path_dir):
            mkdirs(vim_path_dir)
        filecopyto(r'files/vimrc',makepath('/etc','vim','vimrc'))
        if isfile(vim_path):
            remove_file(vim_path)
        filecopyto(r'files/defaults.vim',vim_path)

    if use_old_naming:
        print('Use old network interface naming')
        if isfile('/etc/default/grub'):
            run(r"sed -i 's/#GRUB_DISABLE_LINUX_UUID=true/GRUB_DISABLE_LINUX_UUID=true/' /etc/default/grub")
            run(r"sed -i 's/GRUB_CMDLINE_LINUX=\"\"/GRUB_CMDLINE_LINUX=\"net.ifnames=0 biosdevname=0\"/' /etc/default/grub")
            run('update-grub')

    if use_bashrc:
        print('Copy .bashrc')
        filecopyto(r'files/bashrc_root',r'/root/.bashrc')
        filecopyto(r'files/bashrc_tisadmin',r'/home/tisadmin/.bashrc')

    if pdiff:
        print('Disable APT pdiff')
        run('echo \'Acquire::PDiffs "false";\' > /etc/apt/apt.conf.d/disable-pdiff.conf')
